diff --git a/channels/chan_unistim.c b/channels/chan_unistim.c
index 37a2f59103391936d9dcd3df75099e74ccc02bc9..f96eb360c35f5aaa607e25ce3d19ac5773c589fc 100644
--- a/channels/chan_unistim.c
+++ b/channels/chan_unistim.c
@@ -386,7 +386,7 @@ struct unistim_line {
 	ast_mutex_t lock;
 	/*! Like 200 */
 	char name[80];
-	/*! Like USTM/200@black */
+	/*! Like USTM/200\@black */
 	char fullname[80];
 	/*! pointer to our current connection, channel... */
 	struct unistim_subchannel *subs[MAX_SUBS];
diff --git a/include/asterisk/cli.h b/include/asterisk/cli.h
index f478c4eb0ad7ec034895cd71f6d4857d8f03a6ca..d0db49f483f1525ca015fb44a205f61576d863d4 100644
--- a/include/asterisk/cli.h
+++ b/include/asterisk/cli.h
@@ -220,6 +220,8 @@ char *ast_cli_complete(const char *word, char *const choices[], int pos);
 /*! 
  * \brief Interprets a command
  * Interpret a command s, sending output to fd
+ * \param fd pipe
+ * \param s incoming string
  * \retval 0 on success
  * \retval -1 on failure
  */
@@ -227,14 +229,16 @@ int ast_cli_command(int fd, const char *s);
 
 /*! 
  * \brief Executes multiple CLI commands
- * Interpret strings separated by '\0' and execute each one, sending output to fd
+ * Interpret strings separated by NULL and execute each one, sending output to fd
+ * \param fd pipe
  * \param size is the total size of the string
+ * \param s incoming string
  * \retval number of commands executed
  */
 int ast_cli_command_multiple(int fd, size_t size, const char *s);
 
 /*! \brief Registers a command or an array of commands
- * \param e which cli entry to register
+ * \param e which cli entry to register.
  * Register your own command
  * \retval 0 on success
  * \retval -1 on failure
@@ -252,7 +256,7 @@ int ast_cli_register_multiple(struct ast_cli_entry *e, int len);
  * \brief Unregisters a command or an array of commands
  * \param e which cli entry to unregister
  * Unregister your own command.  You must pass a completed ast_cli_entry structure
- * \return 0.
+ * \return 0
  */
 int ast_cli_unregister(struct ast_cli_entry *e);
 
@@ -280,14 +284,14 @@ int ast_cli_generatornummatches(const char *, const char *);
  *
  * The first entry (offset 0) of the result is the longest common substring
  * in the results, useful to extend the string that has been completed.
- * Subsequent entries are all possible values, followe by a NULL.
+ * Subsequent entries are all possible values, followed by a NULL.
  * All strings and the array itself are malloc'ed and must be freed
  * by the caller.
  */
 char **ast_cli_completion_matches(const char *, const char *);
 
 /*!
- * \brief Command completion for the list of active channels
+ * \brief Command completion for the list of active channels.
  *
  * This can be called from a CLI command completion function that wants to
  * complete from the list of active channels.  'rpos' is the required
diff --git a/include/asterisk/config.h b/include/asterisk/config.h
index 613867937f686f53c021d40fe8cf2e3106b06faf..2064ba5e341750612b0dfd96189d4215d9916ae8 100644
--- a/include/asterisk/config.h
+++ b/include/asterisk/config.h
@@ -113,7 +113,7 @@ struct ast_variable *ast_category_root(struct ast_config *config, char *cat);
 /*! \brief Goes through categories 
  * \param config Which config structure you wish to "browse"
  * \param prev A pointer to a previous category.
- * This funtion is kind of non-intuitive in it's use.  To begin, one passes NULL as the second arguement.  It will return a pointer to the string of the first category in the file.  From here on after, one must then pass the previous usage's return value as the second pointer, and it will return a pointer to the category name afterwards.
+ * This function is kind of non-intuitive in it's use.  To begin, one passes NULL as the second argument.  It will return a pointer to the string of the first category in the file.  From here on after, one must then pass the previous usage's return value as the second pointer, and it will return a pointer to the category name afterwards.
  *
  * \retval a category on success
  * \retval NULL on failure/no-more-categories
diff --git a/include/asterisk/pbx.h b/include/asterisk/pbx.h
index 645c8eeddc6e06830b6688347ea3cfa3b0d5c69e..3479d6f2b0bc299ea42d59058d1a2338ee2bfb0e 100644
--- a/include/asterisk/pbx.h
+++ b/include/asterisk/pbx.h
@@ -529,6 +529,8 @@ int ast_extension_cmp(const char *a, const char *b);
  * \param exten new extension to add
  * \param priority priority of new extension
  * \param callerid callerid of extension
+ * \param found
+ * \param combined_find_spawn 
  *
  * This adds a new extension to the asterisk extension list.
  *
diff --git a/include/asterisk/stringfields.h b/include/asterisk/stringfields.h
index efa290593090555e4ac4788e531aa56feb7f6827..5fe0fc30f311adedec27d6350eda24256147358a 100644
--- a/include/asterisk/stringfields.h
+++ b/include/asterisk/stringfields.h
@@ -303,8 +303,8 @@ int __ast_string_field_init(struct ast_string_field_mgr *mgr,
   \param x Pointer to a structure containing fields
   \param field Name of the field to set
   \param fmt printf-style format string
-  \param args1 arguement one
-  \param args2 arguement two
+  \param args1 argument one
+  \param args2 argument two
   \return nothing
 */
 #define ast_string_field_build_va(x, field, fmt, args1, args2) \
diff --git a/main/ast_expr2f.c b/main/ast_expr2f.c
index c9ae8defdd67e4541ae8a94fb8f7a887f3f0fbc8..a39af463ff3f427d81eb54d10e4cd9ad1147aaa5 100644
--- a/main/ast_expr2f.c
+++ b/main/ast_expr2f.c
@@ -2774,7 +2774,7 @@ YY_BUFFER_STATE ast_yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yys
 
 /** Setup the input buffer state to scan a string. The next call to ast_yylex() will
  * scan from a @e copy of @a str.
- * @param str a NUL-terminated string to scan
+ * @param yy_str a NUL-terminated string to scan
  * @param yyscanner The scanner object.
  * @return the newly allocated buffer state object.
  * @note If you want to scan bytes that may contain NUL values, then use
@@ -2950,7 +2950,7 @@ void ast_yyset_lineno (int  line_number , yyscan_t yyscanner)
 }
 
 /** Set the current column.
- * @param line_number
+ * @param column_no
  * @param yyscanner The scanner object.
  */
 void ast_yyset_column (int  column_no , yyscan_t yyscanner)
diff --git a/pbx/pbx_lua.c b/pbx/pbx_lua.c
index 0465ff9721e085ba260103a74163cd9a7da4ae53..c4701b3d0c30c3ea4f9554173cba1c62e7b34510 100644
--- a/pbx/pbx_lua.c
+++ b/pbx/pbx_lua.c
@@ -868,9 +868,9 @@ static char *lua_read_extensions_file(lua_State *L, long *size)
  * \brief Load the extensions.lua file from the internal buffer
  *
  * \param L the lua_State to use
+ * \param chan channel to work on
  *
  * This function also sets up some constructs used by the extensions.lua file.
- *
  * In the event of an error, an error string will be pushed onto the lua stack.
  *
  * \retval 0 success
diff --git a/res/res_clioriginate.c b/res/res_clioriginate.c
index a0e598434e942340f914de763b618f59557a9027..09cde4d7cc41db152f8a41d293ad46f40a824d3a 100644
--- a/res/res_clioriginate.c
+++ b/res/res_clioriginate.c
@@ -117,9 +117,9 @@ static char *orig_exten(int fd, const char *chan, const char *data)
  * \brief handle for orgination app or exten.
  * \param e pointer to the CLI structure to initialize
  * \param cmd operation to execute
- * \param a structure that contains either application or extension arguements
+ * \param a structure that contains either application or extension arguments
  * \retval CLI_SUCCESS on success.
- * \retval CLI_SHOWUSAGE  on failure.
+ * \retval CLI_SHOWUSAGE on failure.
 */
 static char *handle_orig(struct ast_cli_entry *e, int cmd, struct ast_cli_args *a)
 {
diff --git a/res/res_config_sqlite.c b/res/res_config_sqlite.c
index ae44caf8fad804e1021008b3b03d6ee759e5c0c2..d05a38237bbf4217bcfbb03c13a63cdc8e59a079 100644
--- a/res/res_config_sqlite.c
+++ b/res/res_config_sqlite.c
@@ -448,9 +448,9 @@ static int realtime_destroy_handler(const char *database, const char *table,
 /*!
  * \brief Asterisk callback function for the CLI status command.
  *
- * \param fd file descriptor provided by Asterisk to use with ast_cli()
- * \param argc number of arguments
- * \param argv arguments list
+ * \param e CLI command
+ * \param cmd 
+ * \param a CLI argument list
  * \return RESULT_SUCCESS
  */
 static char *handle_cli_show_sqlite_status(struct ast_cli_entry *e, int cmd, struct ast_cli_args *a);
diff --git a/res/res_convert.c b/res/res_convert.c
index 974cf6ab7ceee255ed02d579210ba9190e847fda..c91c5e7ee529bc88f153526002fbcaf7887218b9 100644
--- a/res/res_convert.c
+++ b/res/res_convert.c
@@ -58,9 +58,9 @@ static int split_ext(char *filename, char **name, char **ext)
 
 /*! 
  * \brief Convert a file from one format to another 
- * \param fd file descriptor
- * \param argc no arguements
- * \param argv list of arguements
+ * \param e CLI entry
+ * \param cmd command number
+ * \param a list of cli arguments
  * \retval CLI_SUCCESS on success.
  * \retval CLI_SHOWUSAGE or CLI_FAILURE on failure.
 */
diff --git a/res/res_crypto.c b/res/res_crypto.c
index b32837b346461836f2d37d9bf3edc62b8fc17dab..e76cab2e84eb14d2c3a78de1d0f1b7a0d33cc764 100644
--- a/res/res_crypto.c
+++ b/res/res_crypto.c
@@ -494,9 +494,9 @@ static void md52sum(char *sum, unsigned char *md5)
 
 /*! 
  * \brief show the list of RSA keys 
- * \param fd file descriptor
- * \param argc no of arguements
- * \param argv list of arguements
+ * \param e CLI command
+ * \param cmd
+ * \param a list of CLI arguments
  * \return RESULT_SUCCESS
 */
 static char *handle_cli_keys_show(struct ast_cli_entry *e, int cmd, struct ast_cli_args *a)
@@ -540,9 +540,9 @@ static char *handle_cli_keys_show(struct ast_cli_entry *e, int cmd, struct ast_c
 
 /*! 
  * \brief initialize all RSA keys  
- * \param fd file descriptor
- * \param argc no of arguements
- * \param argv list of arguements
+ * \param e CLI command
+ * \param cmd 
+ * \param a list of CLI arguments
  * \return RESULT_SUCCESS
 */
 static char *handle_cli_keys_init(struct ast_cli_entry *e, int cmd, struct ast_cli_args *a)
diff --git a/res/res_features.c b/res/res_features.c
index e4fec5305dba640232ce0159ad9625517f6cd91c..56053f91dcef43cccbc2beb902bdd4288aa48041 100644
--- a/res/res_features.c
+++ b/res/res_features.c
@@ -2583,7 +2583,7 @@ static int action_bridge(struct mansession *s, const struct message *m)
  *  
  * Check right usage, lock parking lot, display parked calls, unlock parking lot list.
  * \retval CLI_SUCCESS on success.
- * \retval CLI_SHOWUSAGE on incorrect number of arguements.
+ * \retval CLI_SHOWUSAGE on incorrect number of arguments.
  * \retval NULL when tab completion is used.
 */
 static char *handle_parkedcalls(struct ast_cli_entry *e, int cmd, struct ast_cli_args *a)
diff --git a/res/res_monitor.c b/res/res_monitor.c
index ec770ea61976f5cd5bc6951ae5570440b8617667..3a5aa5914ee127acac4f056da729bada317fe084 100644
--- a/res/res_monitor.c
+++ b/res/res_monitor.c
@@ -80,7 +80,7 @@ static char *monitor_descrip = "  Monitor([file_format[:urlbase],[fname_base],[o
 "          and a target mixed file name which is the same as the leg file names\n"
 "          only without the in/out designator.\n"
 "          If MONITOR_EXEC_ARGS is set, the contents will be passed on as\n"
-"          additional arguements to MONITOR_EXEC\n"
+"          additional arguments to MONITOR_EXEC\n"
 "          Both MONITOR_EXEC and the Mix flag can be set from the\n"
 "          administrator interface\n"
 "\n"
@@ -419,7 +419,7 @@ int ast_monitor_change_fname(struct ast_channel *chan, const char *fname_base, i
 /*!
  * \brief Start monitor
  * \param chan
  * \param data arguements passed  fname|options
  * \retval 0 on success.
  * \retval -1 on failure.
 */
@@ -419,7 +419,7 @@ int ast_monitor_change_fname(struct ast_channel *chan, const char *fname_base, i
  * \brief Start monitor
  * \param chan
- * \param data arguements passed  fname|options
+ * \param data arguments passed fname|options
  * \retval 0 on success.
  * \retval -1 on failure.